@@ -1,12 +1,12 @@
-
 from django.contrib import admin
-from django.contrib.auth.models import User
 
 from mezzanine.accounts.models import get_profile_model
+from mezzanine.utils.models import get_user_model
 from mezzanine.core.admin import SitePermissionUserAdmin
 
 
 Profile = get_profile_model()
+User = get_user_model()
 
 
 class ProfileInline(admin.StackedInline):
