@@ -1,14 +1,9 @@
-try:
-    # Django <= 1.3
-    from django.contrib.syndication.feeds import Feed
-except ImportError:
-    # Django >= 1.4
-    from django.contrib.syndication.views import Feed
+
+from django.contrib.syndication.views import Feed
 from django.core.urlresolvers import reverse
 from django.shortcuts import get_object_or_404
 from django.utils.feedgenerator import Atom1Feed
 from django.utils.html import strip_tags
-from django import VERSION
 
 from mezzanine.blog.models import BlogPost, BlogCategory
 from mezzanine.generic.models import Keyword
@@ -51,13 +46,6 @@ class PostsRSS(Feed):
                 self.title = settings.SITE_TITLE
                 self.description = settings.SITE_TAGLINE
 
-    def get_feed(self, *args, **kwargs):
-        # Django 1.3 author/category/tag filtering.
-        if VERSION < (1, 4) and args[0]:
-            attr, value = args[0].split("/", 1)
-            setattr(self, attr, value)
-        return super(PostsRSS, self).get_feed(*args, **kwargs)
-
     def link(self):
         return reverse("blog_post_feed", kwargs={"format": "rss"})
 
@@ -74,6 +62,9 @@ class PostsRSS(Feed):
         if self.username:
             author = get_object_or_404(User, username=self.username)
             blog_posts = blog_posts.filter(user=author)
+        limit = settings.BLOG_RSS_LIMIT
+        if limit is not None:
+            blog_posts = blog_posts[:settings.BLOG_RSS_LIMIT]
         return blog_posts
 
     def item_description(self, item):
