@@ -4,6 +4,7 @@ from collections import defaultdict
 from django import forms
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
+from django.template.defaultfilters import urlize
 
 from mezzanine.conf import settings, registry
 from mezzanine.conf.models import Setting
@@ -31,7 +32,7 @@ class SettingsForm(forms.Form):
                 field_class = FIELD_TYPES.get(setting["type"], forms.CharField)
                 kwargs = {
                     "label": setting["label"] + ":",
-                    "required": False,
+                    "required": setting["type"] == int,
                     "initial": getattr(settings, name),
                     "help_text": self.format_help(setting["description"]),
                 }
@@ -77,4 +78,4 @@ class SettingsForm(forms.Form):
             for i, s in enumerate(description.split(bold)):
                 parts.append(s if i % 2 == 0 else "<b>%s</b>" % s)
             description = "".join(parts)
-        return mark_safe(description.replace("\n", "<br>"))
+        return mark_safe(urlize(description).replace("\n", "<br>"))
