@@ -52,6 +52,14 @@ register_setting(
     default="",
 )
 
+register_setting(
+    name="BITLY_ACCESS_TOKEN",
+    label=_("bit.ly access token"),
+    description=_("Access token for http://bit.ly URL shortening service."),
+    editable=True,
+    default="",
+)
+
 register_setting(
     name="CACHE_SET_DELAY_SECONDS",
     description=_("Mezzanine's caching uses a technique know as mint "
@@ -118,16 +126,6 @@ register_setting(
     ),
 )
 
-register_setting(
-    name="USE_REVERSION",
-    description=_("If ``True`` and ``django-reversion`` is installed in "
-        "``INSTALLED_APP``, reversion's admin class is injected into all of "
-        "the admin classes that are based upon ``DisplayableAdmin``, "
-        "such as blog admin and all of the page admins."),
-    editable=False,
-    default=False,
-)
-
 register_setting(
     name="FORMS_USE_HTML5",
     description=_("If ``True``, website forms will use HTML5 features."),
@@ -181,6 +179,15 @@ register_setting(
     default="jquery-1.7.1.min.js",
 )
 
+register_setting(
+    name="JQUERY_UI_FILENAME",
+    label=_("Name of the jQuery UI file."),
+    description=_("Name of the jQuery UI file found in "
+                  "mezzanine/core/static/mezzanine/js/"),
+    editable=False,
+    default="jquery-ui-1.9.1.custom.min.js",
+)
+
 register_setting(
     name="MAX_PAGING_LINKS",
     label=_("Max paging links"),
@@ -480,13 +487,13 @@ register_setting(
     description=_("Sequence of setting names available within templates."),
     editable=False,
     default=(
-        "ACCOUNTS_VERIFICATION_REQUIRED", "ADMIN_MEDIA_PREFIX",
-        "BLOG_BITLY_USER", "BLOG_BITLY_KEY", "BLOG_USE_FEATURED_IMAGE",
-        "COMMENTS_DISQUS_SHORTNAME", "COMMENTS_NUM_LATEST",
-        "COMMENTS_DISQUS_API_PUBLIC_KEY", "COMMENTS_DISQUS_API_SECRET_KEY",
-        "COMMENTS_USE_RATINGS", "DEV_SERVER", "FORMS_USE_HTML5",
-        "GRAPPELLI_INSTALLED", "GOOGLE_ANALYTICS_ID", "JQUERY_FILENAME",
-        "LOGIN_URL", "LOGOUT_URL", "SITE_TITLE", "SITE_TAGLINE",
+        "ACCOUNTS_VERIFICATION_REQUIRED", "BITLY_ACCESS_TOKEN",
+        "BLOG_USE_FEATURED_IMAGE", "COMMENTS_DISQUS_SHORTNAME",
+        "COMMENTS_NUM_LATEST", "COMMENTS_DISQUS_API_PUBLIC_KEY",
+        "COMMENTS_DISQUS_API_SECRET_KEY", "COMMENTS_USE_RATINGS",
+        "DEV_SERVER", "FORMS_USE_HTML5", "GRAPPELLI_INSTALLED",
+        "GOOGLE_ANALYTICS_ID", "JQUERY_FILENAME", "LOGIN_URL", "LOGOUT_URL",
+        "SITE_TITLE", "SITE_TAGLINE",
     ),
 )
 
