@@ -9,6 +9,7 @@ from mezzanine.generic.fields import RatingField
 from mezzanine.generic.managers import CommentManager, KeywordManager
 from mezzanine.core.models import Slugged, Orderable
 from mezzanine.conf import settings
+from mezzanine.utils.models import get_user_model_name
 from mezzanine.utils.sites import current_site_id
 
 
@@ -98,7 +99,8 @@ class AssignedKeyword(Orderable):
     A ``Keyword`` assigned to a model instance.
     """
 
-    keyword = models.ForeignKey("Keyword", related_name="assignments")
+    keyword = models.ForeignKey("Keyword", verbose_name=_("Keyword"),
+                                related_name="assignments")
     content_type = models.ForeignKey("contenttypes.ContentType")
     object_pk = models.IntegerField()
     content_object = GenericForeignKey("content_type", "object_pk")
@@ -121,6 +123,8 @@ class Rating(models.Model):
     content_type = models.ForeignKey("contenttypes.ContentType")
     object_pk = models.IntegerField()
     content_object = GenericForeignKey("content_type", "object_pk")
+    user = models.ForeignKey(get_user_model_name(), verbose_name=_("Rater"),
+        null=True, related_name="%(class)ss")
 
     class Meta:
         verbose_name = _("Rating")
@@ -130,7 +134,8 @@ class Rating(models.Model):
         """
         Validate that the rating falls between the min and max values.
         """
-        if self.value not in settings.RATINGS_RANGE:
-            raise ValueError("Invalid rating. %s is not in %s" %
-                             (self.value, ", ".join(settings.RATINGS_RANGE)))
+        valid = map(str, settings.RATINGS_RANGE)
+        if str(self.value) not in valid:
+            raise ValueError("Invalid rating. %s is not in %s" % (self.value,
+                ", ".join(valid)))
         super(Rating, self).save(*args, **kwargs)
